<?php

namespace App\Controller;

use Elastic\Elasticsearch\Client;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

class SearchController extends AbstractController
{
    #[Route('/search', name: 'search', methods: ['GET'])]
    public function executeSearch(Client $client, string $elsIndex, Request $request): Response
    {
        $params = [
            'index' => $elsIndex,
            'body' => [
                'query' => [
                    'query_string' => [
                        'query' => '*' . str_replace('*', '', $request->query->get('search')) . '*',
                        'fields' => [
                            'body',
                            'title'
                        ]
                    ]
                ],
                'highlight' => [
                    "number_of_fragments" => 1,
                    "fragment_size" => 150,
                    'fields' => [
                        'body' => [
                            "pre_tags" => ["<em>"],
                            "post_tags" => ["</em>"]
                        ],
                        'title' => [
                            "pre_tags" => ["<em>"],
                            "post_tags" => ["</em>"]
                        ]
                    ]
                ]
            ]
        ];
        $response = $client->search($params);

        return $this->render('pages/search.html.twig', [
            /** @phpstan-ignore-next-line */
            'hits' => $response['hits']['total']['value'],
            /** @phpstan-ignore-next-line */
            'searchResults' => $response['hits']['hits'],
            'searchText' => str_replace('*', '', $request->query->get('search')),
        ]);
    }
}
