<?php

namespace App\Entity;

use App\Repository\NavigationRepository;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\Common\Collections\Criteria;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Entity(repositoryClass: NavigationRepository::class)]
class Navigation
{
    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column]
    private ?int $id = null;

    #[ORM\Column(length: 255)]
    private ?string $title = null;

    #[ORM\ManyToOne(inversedBy: 'navigations')]
    #[ORM\JoinColumn(nullable: true)]
    private ?Page $page = null;

    #[ORM\ManyToOne(targetEntity: self::class, inversedBy: 'child')]
    private ?self $parent = null;

    #[ORM\OneToMany(mappedBy: 'parent', targetEntity: self::class)]
    private Collection $child;

    #[ORM\Column(length: 255, nullable: true)]
    private ?string $customPath = '#';

    #[ORM\Column]
    private ?int $position = null;

    #[ORM\Column]
    private bool $visible = true;

    #[ORM\Column(nullable: true)]
    private ?int $navOrder = null;

    public function __construct()
    {
        $this->child = new ArrayCollection();
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getTitle(): ?string
    {
        return $this->title;
    }

    public function setTitle(string $title): self
    {
        $this->title = $title;

        return $this;
    }

    public function getPage(): ?Page
    {
        return $this->page;
    }

    public function setPage(?Page $page): self
    {
        $this->page = $page;

        return $this;
    }

    public function getParent(): ?self
    {
        return $this->parent;
    }

    public function setParent(?self $parent): self
    {
        $this->parent = $parent;

        return $this;
    }

    /**
     * @return Collection<int, self>
     */
    public function getChild(): Collection
    {
        $criteria = Criteria::create()
            ->orderBy(array("navOrder" => Criteria::ASC));
        /* @phpstan-ignore-next-line */
        return $this->child->matching($criteria);
    }

    public function addChild(self $child): self
    {
        if (!$this->child->contains($child)) {
            $this->child->add($child);
            $child->setParent($this);
        }

        return $this;
    }

    public function removeChild(self $child): self
    {
        if ($this->child->removeElement($child)) {
            // set the owning side to null (unless already changed)
            if ($child->getParent() === $this) {
                $child->setParent(null);
            }
        }

        return $this;
    }

    public function getCustomPath(): ?string
    {
        return $this->customPath;
    }

    public function setCustomPath(?string $customPath): self
    {
        $this->customPath = $customPath;

        return $this;
    }

    public function getPath(): string
    {
        if ($this->page) {
            return $this->page->getPath();
        }
        return $this->customPath;
    }

    public function getPosition(): ?int
    {
        return $this->position;
    }

    public function setPosition(int $position): self
    {
        $this->position = $position;

        return $this;
    }

    public function isVisible(): ?bool
    {
        return $this->visible;
    }

    public function setVisible(bool $visible): self
    {
        $this->visible = $visible;

        return $this;
    }

    public function getNavOrder(): ?int
    {
        return $this->navOrder;
    }

    public function setNavOrder(?int $navOrder): self
    {
        $this->navOrder = $navOrder;

        return $this;
    }
}
